package cn.com.infosec.asn1.x509.qualified;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.x509.GeneralName;
import java.util.Enumeration;

public class SemanticsInformation extends ASN1Encodable {
   DERObjectIdentifier semanticsIdentifier;
   GeneralName[] nameRegistrationAuthorities;

   public static SemanticsInformation getInstance(Object obj) {
      if (obj != null && !(obj instanceof SemanticsInformation)) {
         if (obj instanceof ASN1Sequence) {
            return new SemanticsInformation(ASN1Sequence.getInstance(obj));
         } else {
            throw new IllegalArgumentException("unknown object in getInstance");
         }
      } else {
         return (SemanticsInformation)obj;
      }
   }

   public SemanticsInformation(ASN1Sequence seq) {
      Enumeration seq1 = seq.getObjects();
      if (seq.size() >= 1) {
         Object var2;
         if ((var2 = seq1.nextElement()) instanceof DERObjectIdentifier) {
            this.semanticsIdentifier = DERObjectIdentifier.getInstance(var2);
            if (seq1.hasMoreElements()) {
               var2 = seq1.nextElement();
            } else {
               var2 = null;
            }
         }

         if (var2 != null) {
            this.nameRegistrationAuthorities = new GeneralName[(seq = ASN1Sequence.getInstance(var2)).size()];

            for(int var4 = 0; var4 < seq.size(); ++var4) {
               this.nameRegistrationAuthorities[var4] = GeneralName.getInstance(seq.getObjectAt(var4));
            }
         }

      } else {
         throw new IllegalArgumentException("no objects in SemanticsInformation");
      }
   }

   public SemanticsInformation(DERObjectIdentifier semanticsIdentifier, GeneralName[] generalNames) {
      this.semanticsIdentifier = semanticsIdentifier;
      this.nameRegistrationAuthorities = generalNames;
   }

   public SemanticsInformation(DERObjectIdentifier semanticsIdentifier) {
      this.semanticsIdentifier = semanticsIdentifier;
      this.nameRegistrationAuthorities = null;
   }

   public SemanticsInformation(GeneralName[] generalNames) {
      this.semanticsIdentifier = null;
      this.nameRegistrationAuthorities = generalNames;
   }

   public DERObjectIdentifier getSemanticsIdentifier() {
      return this.semanticsIdentifier;
   }

   public GeneralName[] getNameRegistrationAuthorities() {
      return this.nameRegistrationAuthorities;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      var1 = new ASN1EncodableVector.<init>();
      DERObjectIdentifier var2;
      if ((var2 = this.semanticsIdentifier) != null) {
         var1.add(var2);
      }

      if (this.nameRegistrationAuthorities != null) {
         ASN1EncodableVector var6;
         var6 = new ASN1EncodableVector.<init>();

         GeneralName[] var4;
         for(int var3 = 0; var3 < (var4 = this.nameRegistrationAuthorities).length; ++var3) {
            var6.add(var4[var3]);
         }

         DERSequence var5;
         var5 = new DERSequence.<init>(var6);
         var1.add(var5);
      }

      return new DERSequence(var1);
   }
}
